# General purpose data pipelines 

A set of base classes and helpers for 
common data pipeline tasks, whether using
in local control scripts or in Airflow tasks.

## !WARNING!
This is a public repository for ease of deployment.
Be especially careful not to commit anything
that shouldn't be here.